package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.RmAlarmRule;
import com.ruoyi.rocketmq.service.IRmAlarmRuleService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 告警规则Controller
 * 
 * @author gyt
 * @date 2025-09-12
 */
@RestController
@RequestMapping("/rule")
public class RmAlarmRuleController extends BaseController
{
    @Autowired
    private IRmAlarmRuleService rmAlarmRuleService;

    /**
     * 查询告警规则列表
     */
    @RequiresPermissions("rocketmq:rule:list")
    @GetMapping("/list")
    public TableDataInfo list(RmAlarmRule rmAlarmRule)
    {
        startPage();
        List<RmAlarmRule> list = rmAlarmRuleService.selectRmAlarmRuleList(rmAlarmRule);
        return getDataTable(list);
    }

    /**
     * 导出告警规则列表
     */
    @RequiresPermissions("rocketmq:rule:export")
    @Log(title = "告警规则", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmAlarmRule rmAlarmRule)
    {
        List<RmAlarmRule> list = rmAlarmRuleService.selectRmAlarmRuleList(rmAlarmRule);
        ExcelUtil<RmAlarmRule> util = new ExcelUtil<RmAlarmRule>(RmAlarmRule.class);
        util.exportExcel(response, list, "告警规则数据");
    }

    /**
     * 获取告警规则详细信息
     */
    @RequiresPermissions("rocketmq:rule:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmAlarmRuleService.selectRmAlarmRuleById(id));
    }

    /**
     * 新增告警规则
     */
    @RequiresPermissions("rocketmq:rule:add")
    @Log(title = "告警规则", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmAlarmRule rmAlarmRule)
    {
        return toAjax(rmAlarmRuleService.insertRmAlarmRule(rmAlarmRule));
    }

    /**
     * 修改告警规则
     */
    @RequiresPermissions("rocketmq:rule:edit")
    @Log(title = "告警规则", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmAlarmRule rmAlarmRule)
    {
        return toAjax(rmAlarmRuleService.updateRmAlarmRule(rmAlarmRule));
    }

    /**
     * 删除告警规则
     */
    @RequiresPermissions("rocketmq:rule:remove")
    @Log(title = "告警规则", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmAlarmRuleService.deleteRmAlarmRuleByIds(ids));
    }
}
